@@ -1,7 +1,8 @@
-use boar::{Boa, BoaStr as Str};
+use boar::{Boa, BoaTo};
 use std::collections::HashMap;
 
 type BoaArray<'b, T, const N: usize> = Boa<'b, [T], [T; N]>;
+type Str<'b> = BoaTo<'b, str>;
 
 #[test]
 fn cmp() {
